==> slang_retail_assistant-6.0.1.tar.gz: lib/src/order_management_user_journey.dart <==
part of slang_retail_assistant;

class OrderManagementUserJourney {
  OrderManagementUserJourney._();

  static const MethodChannel _channel =
      const MethodChannel('plugins.flutter.io/slang_retail_assistant');

  static OrderManagementContext getContext() {
    OrderManagementContext._channel = _channel;
    return const OrderManagementContext();
  }

  static void disablePreserveContext() {
    _channel.invokeMethod("disableOrderManagementUserJourneyContext");
  }

  void setSuccess() {
    _channel.invokeMethod("setOrderManagementSuccess");
  }

  void setFailure() {
    _channel.invokeMethod("setOrderManagementFailure");
  }

  void setOrdersEmpty() {
    _channel.invokeMethod("setOrderManagementOrdersEmpty");
  }

  void setOrderNotFound(int orderIndex) {
    _channel.invokeMapMethod(
        "setOrderManagementOrderNotFound", {"orderIndex": orderIndex});
  }

  void setOrderIndexRequired() {
    _channel.invokeMethod("setOrderManagementOrderIndexRequired");
  }

  void setConfirmationRequired() {
    _channel.invokeMethod("setOrderManagementConfirmationRequired");
  }

  void setUserConfirmedCancel() {
    _channel.invokeMethod("setOrderManagementUserConfirmedCancel");
  }

  void setUserDeniedCancel() {
    _channel.invokeMethod("setOrderManagementUserDeniedCancel");
  }

  void setForceUISelectToCancel() {
    _channel.invokeMethod("setOrderManagementForceUISelectToCancel");
  }

  void setUserJourneyToContinue(
      AssistantUserJourney assistantUserJourney, bool isSpoken) {
    _channel.invokeMapMethod("setUserJourneyToContinue", {
      "currentUserJourney": AssistantUserJourney.ORDER_MANAGEMENT.stringValue,
      "userJourneyToContinue": assistantUserJourney.stringValue,
      "isSpoken": isSpoken
    });
  }

  void clearUserJourneyToContinue() {
    _channel.invokeMapMethod("clearUserJourneyToContinue", {
      "currentUserJourney": AssistantUserJourney.ORDER_MANAGEMENT.stringValue
    });
  }

  void notifyAppState(OrderManagementAppState appState) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel.invokeMapMethod("notifyOrderManagementActionCompleted",
        {"appState": appState.stringValue});
  }
}

class OrderManagementContext {
  const OrderManagementContext();

  static late MethodChannel _channel;

  void clear() {
    _channel.invokeMethod("clearOrderManagementUserJourneyContext");
  }
}

enum OrderManagementAppState {
  UNINITIALIZED,
  UNSUPPORTED,
  WAITING,
  VIEW_ORDER,
  CANCEL_ORDER
}

extension OrderManagementAppStateExtension on OrderManagementAppState {
  String get stringValue {
    switch (this) {
      case OrderManagementAppState.UNSUPPORTED:
        return 'unsupported';
      case OrderManagementAppState.WAITING:
        return 'waiting';
      case OrderManagementAppState.UNINITIALIZED:
        return 'uninitialised';
      case OrderManagementAppState.VIEW_ORDER:
        return 'view_order';
      case OrderManagementAppState.CANCEL_ORDER:
        return "cancel_order";
      default:
        return "unsupported";
    }
  }
}

==> slang_retail_assistant-8.1.0.tar.gz: lib/src/order_management_user_journey.dart <==
part of slang_retail_assistant;

class OrderManagementUserJourney {
  OrderManagementUserJourney._();

  static const MethodChannel _channel =
      const MethodChannel('plugins.flutter.io/slang_retail_assistant');

  static OrderManagementContext getContext() {
    OrderManagementContext._channel = _channel;
    return const OrderManagementContext();
  }

  static void disablePreserveContext() {
    _channel.invokeMethod("disableOrderManagementUserJourneyContext");
  }

  void setUserJourneyToContinue(
      AssistantUserJourney assistantUserJourney, bool isSpoken) {
    _channel.invokeMapMethod("setUserJourneyToContinue", {
      "currentUserJourney": AssistantUserJourney.ORDER_MANAGEMENT.stringValue,
      "userJourneyToContinue": assistantUserJourney.stringValue,
      "isSpoken": isSpoken
    });
  }

  void clearUserJourneyToContinue() {
    _channel.invokeMapMethod("clearUserJourneyToContinue", {
      "currentUserJourney": AssistantUserJourney.ORDER_MANAGEMENT.stringValue
    });
  }

  void notifyAppState(OrderManagementAppState appState) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    String stringAppState = '';
    String? stringAppStateCondition = '';
    stringAppState = appState.getName();
    stringAppStateCondition = appState.getCondition()?.getName();
    _channel.invokeMapMethod("notifyOrderManagementActionCompleted", {
      "appState": stringAppState,
      "appStateCondition": stringAppStateCondition
    });
  }
}

class OrderManagementContext {
  const OrderManagementContext();

  static late MethodChannel _channel;

  void clear() {
    _channel.invokeMethod("clearOrderManagementUserJourneyContext");
  }
}
